@@ -72,6 +72,8 @@ class IPAddress(str):
             socket.inet_aton(value)
         except socket.error:
             raise ValueError("invalid IP address: %r" % value)
+        except TypeError:
+            raise TypeError("value must be a string")
         return str(value)
 
 
@@ -82,10 +84,6 @@ class Hostname(str):
             raise TypeError("value must be a string")
         if value.lower() == 'any':
             return '0.0.0.0'
-        try:
-            socket.inet_aton(socket.gethostbyname(value))
-        except (socket.error, socket.gaierror):
-            raise ValueError("invalid hostname or IP address: %r" % value)
         return str(value)
 
 
@@ -188,23 +186,6 @@ class NetworkRangeList(list):
         return ranges or None
 
 
-class DeprecationMeta(type):
-    """Added temporarily to help with attribute name transitions. Will be removed in 1.2.0"""
-    def __init__(cls, name, bases, dic):
-        from warnings import warn
-        super(DeprecationMeta, cls).__init__(name, bases, dic)
-        if '_defaultPort' in dic:
-            warn('_defaultPort is deprecated in favor of default_port and will be removed in 1.2.0.', DeprecationWarning)
-            cls.default_port = cls._defaultPort
-        elif 'default_port' in dic:
-            cls._defaultPort = cls.default_port
-        if '_name' in dic:
-            warn('_name is deprecated in favor of name and will be removed in 1.2.0.', DeprecationWarning)
-            cls.name = cls._name
-        elif 'name' in dic:
-            cls._name = cls.name
-
-
 class NetworkAddress(tuple):
     """
     A TCP/IP host[:port] network address.
@@ -221,8 +202,6 @@ class NetworkAddress(tuple):
 
     """
 
-    __metaclass__ = DeprecationMeta
-
     default_port = 0
 
     def __new__(cls, value):
