@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2009 Dan Pascu. See LICENSE for details.
+# Copyright (C) 2006-2011 Dan Pascu. See LICENSE for details.
 #
 
 """UNIX process and signal management"""
@@ -10,7 +10,7 @@ import signal
 import atexit
 
 from application import log
-from application.python.util import Singleton
+from application.python.types import Singleton
 
 try:
     set
