@@ -1,9 +1,9 @@
-# Copyright (C) 2009 AG Projects. See LICENSE for details.
+# Copyright (C) 2009-2011 AG Projects. See LICENSE for details.
 #
 
 """Miscellaneous utility descriptors"""
 
-__all__ = ['ThreadLocal', 'WriteOnceAttribute', 'isdescriptor']
+__all__ = ['ThreadLocal', 'WriteOnceAttribute', 'classproperty', 'isdescriptor']
 
 import weakref
 from threading import local
@@ -43,11 +43,12 @@ class ThreadLocal(object):
 
 
 class WriteOnceAttribute(object):
-    """Descriptor that allows objects to have write once attributes.
+    """
+    Descriptor that allows objects to have write once attributes.
 
-       It should be noted that the descriptor only enforces this when directly
-       accessing the object's attribute. It is still possible to modify/delete
-       such an attribute by messing around with the descriptor's internal data.
+    It should be noted that the descriptor only enforces this when directly
+    accessing the object's attribute. It is still possible to modify/delete
+    such an attribute by messing around with the descriptor's internal data.
     """
     def __init__(self):
         self.values = {}
@@ -67,6 +68,18 @@ class WriteOnceAttribute(object):
         raise AttributeError("attribute cannot be deleted")
 
 
+def classproperty(function):
+    """A class level read only property"""
+    class Descriptor(object):
+        def __get__(self, obj, type):
+            return function(type)
+        def __set__(self, obj, value):
+            raise AttributeError("read-only attribute cannot be set")
+        def __delete__(self, obj):
+            raise AttributeError("read-only attribute cannot be deleted")
+    return Descriptor()
+
+
 def isdescriptor(object):
     """Test if `object' is a descriptor"""
     return bool(set(('__get__', '__set__', '__delete__')).intersection(dir(object)))
